@@ -44,14 +44,7 @@ typedef struct {
 
 /* a simple mmap :) */
 
-#ifdef __i386__
-/* regparm exists only on i386 */
-static void *do_mmap(size_t size) __attribute__((regparm(1)));
-static size_t get_index(size_t _size) __attribute__((regparm(1)));
-static void* __small_malloc(size_t _size) __attribute__((regparm(1)));
-#endif
-
-static void *do_mmap(size_t size) {
+static void __attribute__((regparm(1))) *do_mmap(size_t size) {
   return mmap(0, size, PROT_READ|PROT_WRITE, MAP_ANONYMOUS|MAP_PRIVATE, -1, (size_t)0);
 }
 
@@ -70,7 +63,7 @@ static __alloc_t* __small_mem[8];
 
 static inline int __ind_shift() { return (MEM_BLOCK_SIZE==4096)?4:5; }
 
-static size_t get_index(size_t _size) {
+static size_t __attribute__((regparm(1))) get_index(size_t _size) {
   register size_t idx=0;
   if (_size) {
     register size_t size=((_size-1)&(MEM_BLOCK_SIZE-1))>>__ind_shift();
@@ -82,7 +75,7 @@ static size_t get_index(size_t _size) {
 /* small mem */
 static void __small_free(void*_ptr,size_t _size) __attribute__((regparm(2)));
 
-static void __small_free(void*_ptr,size_t _size) {
+static void __attribute__((regparm(2))) __small_free(void*_ptr,size_t _size) {
   __alloc_t* ptr=BLOCK_START(_ptr);
   size_t size=_size;
   size_t idx=get_index(size);
@@ -93,7 +86,7 @@ static void __small_free(void*_ptr,size_t _size) {
   __small_mem[idx]=ptr;
 }
 
-static void* __small_malloc(size_t _size) {
+static void* __attribute__((regparm(1))) __small_malloc(size_t _size) {
   __alloc_t *ptr;
   size_t size=_size;
   size_t idx;
