@@ -4,7 +4,7 @@
 #include <stdlib.h>
 #include "dietwarning.h"
 
-static int set_flags (FILE *stream, int flags) {
+static int set_flags(FILE *stream, int flags) {
   switch (flags) {
     case _IONBF: stream->flags = (stream->flags & ~(BUFLINEWISE)) | NOBUF; break;
     case _IOLBF: stream->flags = (stream->flags & ~(NOBUF)) | BUFLINEWISE; break;
@@ -14,7 +14,7 @@ static int set_flags (FILE *stream, int flags) {
   return 0;
 }
 
-int setvbuf(FILE *stream, char *buf, int flags, size_t size) {
+int setvbuf_unlocked(FILE *stream, char *buf, int flags, size_t size) {
   if (buf) {
     if (!(stream->flags&STATICBUF)) free(stream->buf);
     stream->buf=buf;
@@ -32,3 +32,5 @@ int setvbuf(FILE *stream, char *buf, int flags, size_t size) {
   stream->bm=stream->bs=0;
   return set_flags(stream,flags);
 }
+
+int setvbuf(FILE *stream, char *buf, int flags, size_t size) __attribute__((weak,alias("setvbuf_unlocked")));
