@@ -1,5 +1,6 @@
 #include <asm/unistd.h>
 
-main() {
+int main() {
   syscall(__NR_write,1,"foo\n",4);
+  return 0;
 }
